==> tango_9.5.0+dfsg1.orig.tar.xz: tango-9.5.0/lib/cpp/src/server/tangorollingfileappender.cpp <==
//+=============================================================================
//
// file :         tangorollingfileappender.cpp
//
// description :  Implementation of the DServer logging oriented commands
//
// project :      TANGO
//
// author(s) :    N.Leclercq - SOLEIL
//
// Copyright (C) :      2004,2005,2006,2007,2008,2009,2010,2011,2012,2013,2014,2015
//                        European Synchrotron Radiation Facility
//                      BP 220, Grenoble 38043
//                      FRANCE
//
// This file is part of Tango.
//
// Tango is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Tango is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with Tango.  If not, see <http://www.gnu.org/licenses/>.
//
//
//-=============================================================================

#include <tango/tango.h>

#include <tango/server/tangorollingfileappender.h>

namespace Tango
{
TangoRollingFileAppender::TangoRollingFileAppender(const std::string &name,
                                                   const std::string &fileName,
                                                   size_t maxFileSize) :
    log4tango::RollingFileAppender(name, fileName, maxFileSize * 1024)
{
    // no-op
}

TangoRollingFileAppender::~TangoRollingFileAppender()
{
    // no-op
}

bool TangoRollingFileAppender::isValid(void) const
{
    return (_fd < 0) ? false : true;
}

} // namespace Tango

==> tango_10.0.2+dfsg1.orig.tar.xz: tango-10.0.2/lib/cpp/src/server/tangorollingfileappender.cpp <==
//+=============================================================================
//
// file :         tangorollingfileappender.cpp
//
// description :  Implementation of the DServer logging oriented commands
//
// project :      TANGO
//
// author(s) :    N.Leclercq - SOLEIL
//
// Copyright (C) :      2004,2005,2006,2007,2008,2009,2010,2011,2012,2013,2014,2015
//                        European Synchrotron Radiation Facility
//                      BP 220, Grenoble 38043
//                      FRANCE
//
// This file is part of Tango.
//
// Tango is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Tango is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with Tango.  If not, see <http://www.gnu.org/licenses/>.
//
//
//-=============================================================================

#include <tango/tango.h>

#include <tango/server/tangorollingfileappender.h>

namespace Tango
{
TangoRollingFileAppender::TangoRollingFileAppender(const std::string &name,
                                                   const std::string &fileName,
                                                   size_t maxFileSize) :
    log4tango::RollingFileAppender(name, fileName, maxFileSize * 1024)
{
    // no-op
}

TangoRollingFileAppender::~TangoRollingFileAppender()
{
    // no-op
}

bool TangoRollingFileAppender::isValid() const
{
    return _fd >= 0;
}

} // namespace Tango
